@@ -7,7 +7,7 @@ from typing import Union
 
 async def msg_rule(event: Union[GroupMessageEvent, GuildMessageEvent]) -> bool:
     """Rule 消息规则"""
-    for per_server in get_mc_qq_servers_list():
+    for per_server in mc_qq_servers_list:
         if isinstance(event, GroupMessageEvent):
             if event.group_id in per_server['group_list']:
                 return True
@@ -17,14 +17,25 @@ async def msg_rule(event: Union[GroupMessageEvent, GuildMessageEvent]) -> bool:
     return False
 
 
+async def msg_to_qq_process(json_msg):
+    """处理来自MC的消息，并返回处理后的消息"""
+    message = {
+        "PlayerJoinEvent": f"{json_msg['player']['nickname']} 加入了服务器",
+        "PlayerQuitEvent": f"{json_msg['player']['nickname']} 离开了服务器",
+        "AsyncPlayerChatEvent": f"{json_msg['player']['nickname']} 说：{json_msg['message']}",
+        "PlayerDeathEvent": f"{json_msg['message']}",
+    }
+    return message[json_msg['event_name']]
+
+
 async def send_msg_to_qq(bot: Bot, json_msg):
     """发送消息到 QQ"""
-    msg = json_msg['message']['data']
-    if get_mc_qq_display_server_name():
-        msg = f"[{json_msg['server_name']}] {json_msg['message']['data']}"
+    msg = await msg_to_qq_process(json_msg)
+    if mc_qq_display_server_name:
+        msg = f"[{json_msg['server_name']}] {msg}"
     # 循环服务器列表并发送消息
-    if get_mc_qq_servers_list():
-        for per_server in get_mc_qq_servers_list():
+    if mc_qq_servers_list:
+        for per_server in mc_qq_servers_list:
             if per_server['server_name'] == json_msg['server_name']:
                 if per_server['group_list']:
                     for per_group in per_server['group_list']:
@@ -81,30 +92,26 @@ async def msg_process(bot: Bot, event: Union[GroupMessageEvent, GuildMessageEven
 
     # 初始化消息
     text_msg = member_nickname + "说："
+
     # 初始化消息字典
-    msgDict = {"senderName": member_nickname}
+    messageList = []
 
     # 发送群聊名称
-    message_type = {}
-    if get_mc_qq_send_group_name():
+    if mc_qq_send_group_name:
+        group_name = {'msgType': "group_name"}
         if isinstance(event, GroupMessageEvent):
-            message_type['type'] = "group"
-            message_type['group_name'] = (await bot.get_group_info(group_id=event.group_id))['group_name']
+            group_name['msgData'] = (await bot.get_group_info(group_id=event.group_id))['group_name']
         elif isinstance(event, GuildMessageEvent):
-            message_type['type'] = "guild"
-            message_type['guild_name'] = (await bot.get_guild_meta_by_guest(guild_id=event.guild_id))['guild_name']
+            guild_name = (await bot.get_guild_meta_by_guest(guild_id=event.guild_id))['guild_name']
             for per_channel in (await bot.get_guild_channel_list(guild_id=event.guild_id, no_cache=True)):
                 if str(event.channel_id) == per_channel['channel_id']:
-                    message_type['channel_name'] = per_channel['channel_name']
+                    channel_name = per_channel['channel_name']
+                    group_name['msgData'] = f"{guild_name}丨{channel_name}"
                     break
-    else:
-        message_type['type'] = "group"
-        message_type['group_name'] = ""
-    # 将消息类型以及群聊名称加入消息字典
-    msgDict['message_type'] = message_type
+        messageList.append({"msgType": "group_name", "msgData": group_name})
 
-    # 初始化消息列表
-    messageList = []
+    # 将群成员昵称装入消息列表
+    messageList.append({"msgType": "senderName", "msgData": member_nickname})
 
     for msg in event.message:
         per_msg = {'msgType': msg.type}
@@ -155,9 +162,7 @@ async def msg_process(bot: Bot, event: Union[GroupMessageEvent, GuildMessageEven
         # 放入消息列表
         messageList.append(per_msg)
 
-    # 消息列表添加至总消息
-    msgDict['message'] = messageList
-    return text_msg, str(msgDict)
+    return text_msg, '{"message": ' + str(messageList) + '}'
 
 
 def get_mc_qq_ws_ip() -> str:
@@ -198,3 +203,8 @@ def get_mc_qq_servers_list() -> list:
         return list(get_driver().config.mc_qq_servers_list)
     except AttributeError:
         return []
+
+
+mc_qq_display_server_name = get_mc_qq_display_server_name()
+mc_qq_servers_list = get_mc_qq_servers_list()
+mc_qq_send_group_name = get_mc_qq_send_group_name()
